/*
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2020, 2024. All Rights Reserved.
 *
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *
 */
import { Session } from '@zowe/imperative';
import * as zowe from '@zowe/cli';
import { ICommonJobParms } from '../../doc/input/ICommonJobParms';
import { IGetJobsParms } from '../../doc/input/IGetJobsParms';
import { IRestApiResponse } from '../../doc/IRestApiResponse';
import { IJob, IJobFile } from '../../doc/response';
import { IMonitorJobWaitForParms } from '../..';
/**
 * Class to handle obtaining of z/OS batch job information
 * @export
 * @class GetJobs
 */
export declare class GetJobs {
    /**
     * Get jobs (defaults to the user ID of the session as owner)
     * @static
     * @param {Session}             session  - RSE connection info
     * @returns {Promise<IJob[]>}            - promise that resolves to an array of IJob objects (matching jobs)
     * @memberof GetJobs
     */
    static getJobs(session: Session, options?: IGetJobsParms): Promise<IRestApiResponse>;
    /**
     * Get jobs that match a job name preixl
     * Defaults to jobs owned by the user ID in the session.
     * @static
     * @param {Session} session - connection info
     * @param {string} prefix - job name prefix for which to list jobs. Supports wildcard e.g. JOBNM*
     *                          returns jobs with names starting with "JOBNM"
     * @returns {Promise<IJob[]>} - promise that resolves to an array of IJob objects (matching jobs)
     * @memberof GetJobs
     */
    static getJobsByPrefix(session: Session, prefix: string): Promise<IRestApiResponse>;
    /**
     * Get jobs that are owned by a certain user or pattern of users
     * @static
     * @param {Session} session - RSE connection info
     * @param {string} owner - owner for which to get jobs. Supports wildcard e.g. IBMU* returns jobs owned by
     *                         all users whose ID beings with "IBMU"
     * @returns {Promise<IJob[]>} - promise that resolves to an array of IJob objects (matching jobs)
     * @memberof GetJobs
     */
    static getJobsByOwner(session: Session, owner: string): Promise<IRestApiResponse>;
    /**
     * Get a list of jobs that match an owner and prefix
     * @static
     * @param {Session} session - RSE connection info
     * @param {string}  owner   - owner for which to get jobs. Supports wildcard e.g. IBMU* returns jobs owned by
     *                         all users whose ID beings with "IBMU"
     * @param {string}  prefix  - prefix for which to get jobs. Supports wildcard e.g. JOBNM*
     *                          returns jobs with names starting with "JOBNM"
     * @returns {Promise<IRestApiResponse>}
     * @memberof GetJobs
     */
    static getJobsByOwnerAndPrefix(session: Session, options?: IGetJobsParms): Promise<IRestApiResponse>;
    static getJobsByParameters(session: Session, options?: IGetJobsParms): Promise<IRestApiResponse>;
    /**
     * Get a single job object from an input job id
     * @static
     * @param {Session} session - RSE connection info
     * @param {string} jobid    - the job ID for the job for which you want to get status
     * @param {boolean} attributes - query more job attributes when it is set to true
     * @returns {Promise<IJob>}
     * @memberof GetJobs
     */
    static getJob(session: Session, jobid: string, attributes?: boolean): Promise<IJob>;
    /**
     * Get jobs filtered by owner and prefix.
     * @static
     * @param {Session}     session - RSE connection info
     * @param {IGetJobsParms} parms - parm object (see IGetJobsParms interface for details)
     * @returns { Promise<IRestApiResponse>}
     * @memberof GetJobs
     */
    static getJobsCommon(session: Session, parms?: IGetJobsParms): Promise<IRestApiResponse>;
    /**
     * Get the status and other details (e.g. owner, return code) for a job
     * @static
     * @param {Session}         session - RSE connection info
     * @param {ICommonJobParms} parms   - parm object (see ICommonJobParms interface for details)
     * @returns {Promise<IJob>}         - promise that resolves to an IJob object representing the job
     * @memberof GetJobs
     */
    static getStatusCommon(session: Session, parms: IMonitorJobWaitForParms): Promise<object>;
    /**
     * Get a list of all spool files for a job.
     * @static
     * @param {Session} session - RSE connection info
     * @param {string} jobname  - the job name for the job for which you want to get a list of spool files
     * @param {string} jobid    - the job ID for the job for which you want to get a list of spool files
     * @returns {Promise<IJobFile[]>} - promise that resolves to an array of IJobFile objects
     * @memberof GetJobs
     */
    static getSpoolFiles(session: Session, jobName: string, jobId: string): Promise<IRestApiResponse>;
    /**
     * Get a list of all job spool files for a job
     * Alternate version of the API that accepts an IJob object returned by
     * other APIs such as SubmitJobs.
     * @static
     * @param {Session} session - RSE connection info
     * @param {IJob} job        - the job for which you would like to get a list of job spool files
     * @returns {Promise<IRestApiResponse>} - promise that resolves to an array of IJobFile objects
     * @memberof GetJobs
     */
    static getSpoolFilesForJob(session: Session, job: IJob): Promise<IRestApiResponse>;
    /**
     * Get a list of all job spool files for a job.
     * @static
     * @param {Session}         session - RSE connection info
     * @param {ICommonJobParms} parms   - parm object (see for details)
     * @returns {Promise<IRestApiResponse>} - promise that resolves to an array of IJobFile objectsl
     * @memberof GetJobs
     */
    static getSpoolFilesCommon(session: Session, parms: ICommonJobParms): Promise<IRestApiResponse>;
    /**
     * Get spool content from a job (keeping naming convention patter with this duplication function).
     * @static
     * @param {Session} session - RSE connection info
     * @param           jobFile - the spool file for which you want to retrieve the content
     * @returns {Promise<string>} - promise that resolves to the spool content
     * @memberof GetJobs
     */
    static getSpoolContent(session: Session, jobFile: IJobFile): Promise<string>;
    /**
     * Get spool content from a job using the job name, job ID, and spool ID number from RSE
     * @static
     * @param {Session} session - RSE connection info
     * @param           jobname - the job name for the job containing the spool content
     * @param           jobid   - the job id for the job containing the spool content
     * @param           spoolId - id number assigned by the jobs api that identifies the particular job spool file (DD)
     * @returns {Promise<string>} - promise that resolves to the spool content
     * @memberof GetJobs
     */
    static getSpoolContentById(session: Session, jobname: string, jobid: string, spoolId: number): Promise<IRestApiResponse>;
    /**
     * Get spool content from a job.
     * @static
     * @param {Session} session - RSE connection info
     * @param           jobFile - the spool file for which you want to retrieve the content
     * @returns {Promise<string>} - promise that resolves to the spool content
     * @memberof GetJobs
     */
    static getSpoolContentCommon(session: Session, jobFile: IJobFile): Promise<string>;
    /**
     * Get JCL from a job.
     * Alternate version of the API that accepts an IJob object returned by
     * other APIs such as SubmitJobs.
     * @static
     * @param {Session} session - RSE connection info
     * @param {IJob}    job     - the job for which you would like to retrieve JCL
     * @returns {Promise<string>} - promise that resolves to JCL content
     * @memberof GetJobs
     */
    static getJclForJob(session: Session, job: IJob): Promise<string>;
    /**
     * Get the JCL that was used to submit a job.
     * @static
     * @param {Session}         session - RSE connection info
     * @param {ICommonJobParms} parms   - parm object (see ICommonJobParms interface for details)
     * @returns {Promise<string>}       - promise that resolves to the JCL content
     * @memberof GetJobs
     */
    static getJclCommon(session: Session, parms: zowe.ICommonJobParms): Promise<string>;
    /**
     * Get Log
     * @returns {Logger} applicationLogger.
     */
    private static get log();
}
